@@ -1,10 +1,6 @@
-/***************************************************************************
- *                                                                         *
- *   SPDX-FileCopyrightText: 2020 Rinigus <rinigus.git@gmail.com>          *
- *                                                                         *
- *   SPDX-License-Identifier: GPL-2.0-or-later                             *
- *                                                                         *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Rinigus <rinigus.git@gmail.com>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef URLOBSERVER_H
 #define URLOBSERVER_H
@@ -25,7 +21,7 @@ public:
 
     bool bookmarked() const;
 
-signals:
+Q_SIGNALS:
     void urlChanged(const QString &url);
     void bookmarkedChanged(bool bookmarked);
 
