@@ -28,6 +28,7 @@
 #include "angelfishwebprofile.h"
 #include "bookmarkshistorymodel.h"
 #include "browsermanager.h"
+#include "domdistiller.h"
 #include "downloadsmodel.h"
 #include "iconimageprovider.h"
 #include "tabsmodel.h"
@@ -80,13 +81,14 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QObject::connect(&service, &KDBusService::activateRequested, &app, [&parser, &engine](const QStringList &arguments) {
         parser.parse(arguments);
 
+        auto *webbrowserWindow = qobject_cast<QQuickWindow *>(engine.rootObjects().constFirst());
+        if (!webbrowserWindow) {
+            qWarning() << "No webbrowser window is open, can't activate";
+            return;
+        }
+
         if (!parser.positionalArguments().isEmpty()) {
             const QUrl initialUrl = QUrl::fromUserInput(parser.positionalArguments().constFirst());
-            const auto *webbrowserWindow = qobject_cast<QQuickWindow *>(engine.rootObjects().constFirst());
-            if (!webbrowserWindow) {
-                qWarning() << "No webbrowser window is open, can't open the url";
-                return;
-            }
             const auto *pageStack = webbrowserWindow->property("pageStack").value<QObject *>();
             const auto *initialPage = pageStack->property("initialPage").value<QObject *>();
 
@@ -100,10 +102,11 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
             auto *tabsModel = regularTabs->property("tabsModel").value<TabsModel *>();
             // Open new tab with requested url
             tabsModel->newTab(initialUrl);
-
-            // Move window to the front
-            KWindowSystem::raiseWindow(webbrowserWindow->winId());
         }
+
+        // Move window to the front
+        KWindowSystem::updateStartupId(webbrowserWindow);
+        KWindowSystem::activateWindow(webbrowserWindow);
     });
 
     // register as early possible so it has time to load, constructor doesn't block
@@ -135,6 +138,11 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterType<WebAppCreator>(APPLICATION_ID, 1, 0, "WebAppCreator");
     qmlRegisterAnonymousType<QWebEngineUrlRequestInterceptor>(APPLICATION_ID, 1);
 
+    // Dom Distiller
+    qmlRegisterSingletonType<DomDistiller>(APPLICATION_ID, 1, 0, "DomDistiller", [](QQmlEngine *, QJSEngine *) -> QObject * {
+        return new DomDistiller();
+    });
+
     // URL utils
     qmlRegisterSingletonType<UrlUtils>(APPLICATION_ID, 1, 0, "UrlUtils", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return new UrlUtils();
